pub enum CrossCompileAssistance {
NoAssistance,
HelpText(String),
Configuration {
cargo_env: Vec<(OsString, OsString)>,
},
}Variants
NoAssistance
No specific assistance available for the current host and target platform combination.
HelpText(String)
A human-readable help text with instructions on how to setup the host machine for cross-compilation.
Configuration
Required configuration to cross-compile to the target platform.